==> easydata-0.0.7-py2.py3-none-any.whl: tests/factory/models.py <==
from easydata import ItemModel, parsers
from easydata.processors import DataJsonToDictProcessor, ItemDiscountProcessor
from easydata.queries import jp, pq


class ProductModel(ItemModel):
    item_language = "en"

    item_tags = ["phones", "ecommerce"]

    item_temp_brand = parsers.Text(jp("brand"), source="json_data")

    item_designer = parsers.Text(from_item="brand")

    item_name = parsers.Text(pq(".name::text"))

    def item_stock(self, data):
        return data["json_data"]["info"]["stock"]


class ProductSimpleWithProcessDataModel(ItemModel):
    item_brand = parsers.Text(jp("brand"))

    item_brand_type = parsers.Text(source="brand_type")

    data_processors = [DataJsonToDictProcessor()]

    def preprocess_data(self, data):
        data["data"] = data["data"] + "}"
        return data

    def process_data(self, data):
        if "easydata" in data["data"]["brand"].lower():
            data["brand_type"] = "local"
        else:
            data["brand_type"] = "other"

        return data


class ProductSimpleWithProcessItemModel(ItemModel):
    item_price = parsers.PriceFloat(jp("price"))

    item_temp_sale_price = parsers.PriceFloat(jp("sale_price"))

    item_processors = [ItemDiscountProcessor()]

    def preprocess_item(self, item):
        if item["sale_price"] <= 1:
            item["sale_price"] = 0

        return item

    def process_item(self, item):
        item["final_sale"] = bool(item["discount"])

        return item


class PricingBlockModel(ItemModel):
    item_price = parsers.PriceFloat(pq("#price::text"))

    item_sale_price = parsers.PriceFloat(pq("#sale-price::text"))

    item_processors = [("discount", ItemDiscountProcessor())]


class SettingsBlockModel(ItemModel):
    item_calling_code = 44

    item_country = "UK"

==> easydata-0.0.10-py2.py3-none-any.whl: tests/factory/models.py <==
from easydata import ItemModel, parsers
from easydata.processors import DataJsonToDictProcessor, ItemDiscountProcessor
from easydata.queries import jp, pq


class ProductModel(ItemModel):
    item_language = "en"

    item_tags = ["phones", "ecommerce"]

    _item_brand = parsers.Text(jp("brand"), source="json_data")

    item_designer = parsers.Text(from_item="brand")

    item_name = parsers.Text(pq(".name::text"))

    def item_stock(self, data):
        return data["json_data"]["info"]["stock"]


class ProductSimpleWithProcessDataModel(ItemModel):
    item_brand = parsers.Text(jp("brand"))

    item_brand_type = parsers.Text(source="brand_type")

    data_processors = [DataJsonToDictProcessor()]

    def preprocess_data(self, data):
        data["data"] = data["data"] + "}"
        return data

    def process_data(self, data):
        if "easydata" in data["data"]["brand"].lower():
            data["brand_type"] = "local"
        else:
            data["brand_type"] = "other"

        return data


class ProductSimpleWithProcessItemModel(ItemModel):
    item_price = parsers.PriceFloat(jp("price"))

    _item_sale_price = parsers.PriceFloat(jp("sale_price"))

    item_processors = [ItemDiscountProcessor()]

    def preprocess_item(self, item):
        if item["sale_price"] <= 1:
            item["sale_price"] = 0

        return item

    def process_item(self, item):
        item["final_sale"] = bool(item["discount"])

        return item


class PricingBlockModel(ItemModel):
    item_price = parsers.PriceFloat(pq("#price::text"))

    item_sale_price = parsers.PriceFloat(pq("#sale-price::text"))

    item_processors = [("discount", ItemDiscountProcessor())]


class SettingsBlockModel(ItemModel):
    item_calling_code = 44

    item_country = "UK"
